/** 
 *   Thermometer TC6003P
 *
 *   (c) Copyright 2005 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

#define _GNU_SOURCE


#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>
#include <unistd.h>
#include "ther_1529.h"
#include "my_stdio.h"



int main(int argc, char * const argv[])
{
	int fd;
	int op;
	int loop = 0;
	double temperature;
	char *device = THER_1529_DEVICE;
	
	INCREMENT_VERBOSE_FLAG();

	while  ((op = getopt(argc, argv, "vhd:l")) != EOF)
		switch( op ){
#ifdef VERBOSE_MODE
		case 'v':
			verbose_flag = (verbose_flag << 1) | 1;
			break;
#endif
		case 'd':
			device = optarg;
			break;
		case 'l':
			loop = 1;
			break;
		case 'h':
		default:
			printf("Use %s [-v (incremental)] [-h] [-d device (def: %s)][-l]\n", 
			       argv[0], THER_1529_DEVICE);
			exit(-1);
		}
	
	if ((fd = ther1529_open(device)) < 0) {
		perror("Thermometer open");
		return -1;
	}	
	do {
		if (ther1529_get(fd, &temperature) == 0) {
			printf("Temperature: %8.4f\n", temperature);
		}
		if (loop) sleep(1);
	} while(loop);
	ther1529_close(fd);

	return 0;
}
